# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .account_project import *
from .account_ssh_key import *
from .apple_slicon_valley_server import *
from .baremetal_server import *
from .block_snapshot import *
from .block_volume import *
from .cockpit import *
from .cockpit_grafana_user import *
from .cockpit_token import *
from .container import *
from .container_cron import *
from .container_domain import *
from .container_namespace import *
from .container_token import *
from .container_trigger import *
from .database import *
from .database_acl import *
from .database_backup import *
from .database_instance import *
from .database_privilege import *
from .database_read_replica import *
from .database_user import *
from .documentdb_database import *
from .documentdb_instance import *
from .documentdb_private_network_endpoint import *
from .documentdb_privilege import *
from .documentdb_read_replica import *
from .documentdb_user import *
from .domain_record import *
from .domain_zone import *
from .flexible_ip import *
from .flexible_ip_mac_address import *
from .function import *
from .function_cron import *
from .function_domain import *
from .function_namespace import *
from .function_token import *
from .function_trigger import *
from .get_account_project import *
from .get_account_ssh_key import *
from .get_availability_zones import *
from .get_baremetal_offer import *
from .get_baremetal_option import *
from .get_baremetal_os import *
from .get_baremetal_server import *
from .get_billing_consumptions import *
from .get_billing_invoices import *
from .get_block_snapshot import *
from .get_block_volume import *
from .get_cockpit import *
from .get_cockpit_plan import *
from .get_container import *
from .get_container_namespace import *
from .get_database import *
from .get_database_acl import *
from .get_database_backup import *
from .get_database_instance import *
from .get_database_privilege import *
from .get_documentdb_database import *
from .get_documentdb_instance import *
from .get_documentdb_load_balancer_endpoint import *
from .get_domain_record import *
from .get_domain_zone import *
from .get_flexible_ip import *
from .get_flexible_ips import *
from .get_function import *
from .get_function_namespace import *
from .get_iam_application import *
from .get_iam_group import *
from .get_iam_ssh_key import *
from .get_iam_user import *
from .get_instance_image import *
from .get_instance_ip import *
from .get_instance_placement_group import *
from .get_instance_private_nic import *
from .get_instance_security_group import *
from .get_instance_server import *
from .get_instance_servers import *
from .get_instance_snapshot import *
from .get_instance_volume import *
from .get_iot_device import *
from .get_iot_hub import *
from .get_ipam_ip import *
from .get_ipam_ips import *
from .get_k8s_version import *
from .get_kubernetes_cluster import *
from .get_kubernetes_node_pool import *
from .get_lb_acls import *
from .get_lb_backend import *
from .get_lb_backends import *
from .get_lb_frontend import *
from .get_lb_frontends import *
from .get_lb_ips import *
from .get_lb_route import *
from .get_lb_routes import *
from .get_lbs import *
from .get_loadbalancer import *
from .get_loadbalancer_certificate import *
from .get_loadbalancer_ip import *
from .get_marketplace_image import *
from .get_mnq_sqs import *
from .get_object_bucket import *
from .get_object_bucket_policy import *
from .get_redis_cluster import *
from .get_registry_image import *
from .get_registry_namespace import *
from .get_secret import *
from .get_secret_version import *
from .get_tem_domain import *
from .get_vpc import *
from .get_vpc_gateway_network import *
from .get_vpc_private_network import *
from .get_vpc_public_gateway import *
from .get_vpc_public_gateway_dhcp import *
from .get_vpc_public_gateway_dhcp_reservation import *
from .get_vpc_public_gateway_ip import *
from .get_vpc_public_pat_rule import *
from .get_vpcs import *
from .get_web_host_offer import *
from .get_webhosting import *
from .iam_api_key import *
from .iam_application import *
from .iam_group import *
from .iam_group_membership import *
from .iam_policy import *
from .iam_ssh_key import *
from .iam_user import *
from .instance_image import *
from .instance_ip import *
from .instance_ip_reverse_dns import *
from .instance_placement_group import *
from .instance_private_nic import *
from .instance_security_group import *
from .instance_security_group_rules import *
from .instance_server import *
from .instance_snapshot import *
from .instance_user_data import *
from .instance_volume import *
from .iot_device import *
from .iot_hub import *
from .iot_network import *
from .iot_route import *
from .ipam_ip import *
from .ipam_ip_reverse_dns import *
from .job_definition import *
from .kubernetes_cluster import *
from .kubernetes_node_pool import *
from .loadbalancer import *
from .loadbalancer_acl import *
from .loadbalancer_backend import *
from .loadbalancer_certificate import *
from .loadbalancer_frontend import *
from .loadbalancer_ip import *
from .loadbalancer_route import *
from .mnq_nats_account import *
from .mnq_nats_credentials import *
from .mnq_sns import *
from .mnq_sns_credentials import *
from .mnq_sns_topic import *
from .mnq_sns_topic_subscription import *
from .mnq_sqs import *
from .mnq_sqs_credentials import *
from .mnq_sqs_queue import *
from .object_bucket import *
from .object_bucket_acl import *
from .object_bucket_lock_configuration import *
from .object_bucket_policy import *
from .object_bucket_website_configuration import *
from .object_item import *
from .provider import *
from .redis_cluster import *
from .registry_namespace import *
from .sdb_database import *
from .secret import *
from .secret_version import *
from .tem_domain import *
from .vpc import *
from .vpc_gateway_network import *
from .vpc_private_network import *
from .vpc_public_gateway import *
from .vpc_public_gateway_dhcp import *
from .vpc_public_gateway_dhcp_reservation import *
from .vpc_public_gateway_ip import *
from .vpc_public_gateway_ip_reverse_dns import *
from .vpc_public_gateway_pat_rule import *
from .webhosting import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumiverse_scaleway.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumiverse_scaleway.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "scaleway",
  "mod": "index/accountProject",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/accountProject:AccountProject": "AccountProject"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/accountSshKey",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/accountSshKey:AccountSshKey": "AccountSshKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/appleSliconValleyServer",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/appleSliconValleyServer:AppleSliconValleyServer": "AppleSliconValleyServer"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/baremetalServer",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/baremetalServer:BaremetalServer": "BaremetalServer"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/blockSnapshot",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/blockSnapshot:BlockSnapshot": "BlockSnapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/blockVolume",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/blockVolume:BlockVolume": "BlockVolume"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/cockpit",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/cockpit:Cockpit": "Cockpit"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/cockpitGrafanaUser",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/cockpitGrafanaUser:CockpitGrafanaUser": "CockpitGrafanaUser"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/cockpitToken",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/cockpitToken:CockpitToken": "CockpitToken"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/container",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/container:Container": "Container"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/containerCron",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/containerCron:ContainerCron": "ContainerCron"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/containerDomain",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/containerDomain:ContainerDomain": "ContainerDomain"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/containerNamespace",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/containerNamespace:ContainerNamespace": "ContainerNamespace"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/containerToken",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/containerToken:ContainerToken": "ContainerToken"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/containerTrigger",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/containerTrigger:ContainerTrigger": "ContainerTrigger"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/database",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/database:Database": "Database"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databaseAcl",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databaseAcl:DatabaseAcl": "DatabaseAcl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databaseBackup",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databaseBackup:DatabaseBackup": "DatabaseBackup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databaseInstance",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databaseInstance:DatabaseInstance": "DatabaseInstance"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databasePrivilege",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databasePrivilege:DatabasePrivilege": "DatabasePrivilege"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databaseReadReplica",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databaseReadReplica:DatabaseReadReplica": "DatabaseReadReplica"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databaseUser",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databaseUser:DatabaseUser": "DatabaseUser"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/documentdbDatabase",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/documentdbDatabase:DocumentdbDatabase": "DocumentdbDatabase"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/documentdbInstance",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/documentdbInstance:DocumentdbInstance": "DocumentdbInstance"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/documentdbPrivateNetworkEndpoint",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/documentdbPrivateNetworkEndpoint:DocumentdbPrivateNetworkEndpoint": "DocumentdbPrivateNetworkEndpoint"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/documentdbPrivilege",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/documentdbPrivilege:DocumentdbPrivilege": "DocumentdbPrivilege"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/documentdbReadReplica",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/documentdbReadReplica:DocumentdbReadReplica": "DocumentdbReadReplica"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/documentdbUser",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/documentdbUser:DocumentdbUser": "DocumentdbUser"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/domainRecord",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/domainRecord:DomainRecord": "DomainRecord"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/domainZone",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/domainZone:DomainZone": "DomainZone"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/flexibleIp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/flexibleIp:FlexibleIp": "FlexibleIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/flexibleIpMacAddress",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/flexibleIpMacAddress:FlexibleIpMacAddress": "FlexibleIpMacAddress"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/function",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/function:Function": "Function"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/functionCron",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/functionCron:FunctionCron": "FunctionCron"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/functionDomain",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/functionDomain:FunctionDomain": "FunctionDomain"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/functionNamespace",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/functionNamespace:FunctionNamespace": "FunctionNamespace"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/functionToken",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/functionToken:FunctionToken": "FunctionToken"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/functionTrigger",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/functionTrigger:FunctionTrigger": "FunctionTrigger"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamApiKey",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamApiKey:IamApiKey": "IamApiKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamApplication",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamApplication:IamApplication": "IamApplication"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamGroup",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamGroup:IamGroup": "IamGroup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamGroupMembership",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamGroupMembership:IamGroupMembership": "IamGroupMembership"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamPolicy",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamPolicy:IamPolicy": "IamPolicy"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamSshKey",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamSshKey:IamSshKey": "IamSshKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamUser",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamUser:IamUser": "IamUser"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceImage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceImage:InstanceImage": "InstanceImage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceIp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceIp:InstanceIp": "InstanceIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceIpReverseDns",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceIpReverseDns:InstanceIpReverseDns": "InstanceIpReverseDns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instancePlacementGroup",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instancePlacementGroup:InstancePlacementGroup": "InstancePlacementGroup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instancePrivateNic",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instancePrivateNic:InstancePrivateNic": "InstancePrivateNic"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceSecurityGroup",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceSecurityGroup:InstanceSecurityGroup": "InstanceSecurityGroup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceSecurityGroupRules",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceSecurityGroupRules:InstanceSecurityGroupRules": "InstanceSecurityGroupRules"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceServer",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceServer:InstanceServer": "InstanceServer"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceSnapshot",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceSnapshot:InstanceSnapshot": "InstanceSnapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceUserData",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceUserData:InstanceUserData": "InstanceUserData"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceVolume",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceVolume:InstanceVolume": "InstanceVolume"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iotDevice",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iotDevice:IotDevice": "IotDevice"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iotHub",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iotHub:IotHub": "IotHub"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iotNetwork",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iotNetwork:IotNetwork": "IotNetwork"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iotRoute",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iotRoute:IotRoute": "IotRoute"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/ipamIp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/ipamIp:IpamIp": "IpamIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/ipamIpReverseDns",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/ipamIpReverseDns:IpamIpReverseDns": "IpamIpReverseDns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/jobDefinition",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/jobDefinition:JobDefinition": "JobDefinition"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/kubernetesCluster",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/kubernetesCluster:KubernetesCluster": "KubernetesCluster"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/kubernetesNodePool",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/kubernetesNodePool:KubernetesNodePool": "KubernetesNodePool"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancer",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancer:Loadbalancer": "Loadbalancer"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerAcl",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerAcl:LoadbalancerAcl": "LoadbalancerAcl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerBackend",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerBackend:LoadbalancerBackend": "LoadbalancerBackend"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerCertificate",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerCertificate:LoadbalancerCertificate": "LoadbalancerCertificate"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerFrontend",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerFrontend:LoadbalancerFrontend": "LoadbalancerFrontend"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerIp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerIp:LoadbalancerIp": "LoadbalancerIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerRoute",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerRoute:LoadbalancerRoute": "LoadbalancerRoute"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqNatsAccount",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqNatsAccount:MnqNatsAccount": "MnqNatsAccount"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqNatsCredentials",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqNatsCredentials:MnqNatsCredentials": "MnqNatsCredentials"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSns",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSns:MnqSns": "MnqSns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSnsCredentials",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSnsCredentials:MnqSnsCredentials": "MnqSnsCredentials"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSnsTopic",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSnsTopic:MnqSnsTopic": "MnqSnsTopic"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSnsTopicSubscription",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSnsTopicSubscription:MnqSnsTopicSubscription": "MnqSnsTopicSubscription"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSqs",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSqs:MnqSqs": "MnqSqs"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSqsCredentials",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSqsCredentials:MnqSqsCredentials": "MnqSqsCredentials"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSqsQueue",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSqsQueue:MnqSqsQueue": "MnqSqsQueue"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectBucket",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectBucket:ObjectBucket": "ObjectBucket"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectBucketAcl",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectBucketAcl:ObjectBucketAcl": "ObjectBucketAcl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectBucketLockConfiguration",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectBucketLockConfiguration:ObjectBucketLockConfiguration": "ObjectBucketLockConfiguration"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectBucketPolicy",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectBucketPolicy:ObjectBucketPolicy": "ObjectBucketPolicy"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectBucketWebsiteConfiguration",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectBucketWebsiteConfiguration:ObjectBucketWebsiteConfiguration": "ObjectBucketWebsiteConfiguration"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectItem",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectItem:ObjectItem": "ObjectItem"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/redisCluster",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/redisCluster:RedisCluster": "RedisCluster"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/registryNamespace",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/registryNamespace:RegistryNamespace": "RegistryNamespace"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/sdbDatabase",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/sdbDatabase:SdbDatabase": "SdbDatabase"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/secret",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/secretVersion",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/secretVersion:SecretVersion": "SecretVersion"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/temDomain",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/temDomain:TemDomain": "TemDomain"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpc",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpc:Vpc": "Vpc"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcGatewayNetwork",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcGatewayNetwork:VpcGatewayNetwork": "VpcGatewayNetwork"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPrivateNetwork",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPrivateNetwork:VpcPrivateNetwork": "VpcPrivateNetwork"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGateway",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGateway:VpcPublicGateway": "VpcPublicGateway"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGatewayDhcp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGatewayDhcp:VpcPublicGatewayDhcp": "VpcPublicGatewayDhcp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGatewayDhcpReservation",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGatewayDhcpReservation:VpcPublicGatewayDhcpReservation": "VpcPublicGatewayDhcpReservation"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGatewayIp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGatewayIp:VpcPublicGatewayIp": "VpcPublicGatewayIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGatewayIpReverseDns",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGatewayIpReverseDns:VpcPublicGatewayIpReverseDns": "VpcPublicGatewayIpReverseDns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGatewayPatRule",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGatewayPatRule:VpcPublicGatewayPatRule": "VpcPublicGatewayPatRule"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/webhosting",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/webhosting:Webhosting": "Webhosting"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "scaleway",
  "token": "pulumi:providers:scaleway",
  "fqn": "pulumiverse_scaleway",
  "class": "Provider"
 }
]
"""
)
